@@ -125,7 +125,7 @@ void ActionManager::toggleMenubar(bool dontShowWarning)
             mMenuBar->show();
         } else {
             if (!dontShowWarning && (!mToolBar->isVisible() || !mToolBar->actions().contains(mHamburgerMenu))) {
-                const QString accel = mShowMenuBarAction->shortcut().toString();
+                const QString accel = mShowMenuBarAction->shortcut().toString(QKeySequence::NativeText);
                 KMessageBox::information(mCalendarView,
                                          i18n("<qt>This will hide the menu bar completely."
                                               " You can show it again by typing %1.</qt>",
@@ -190,6 +190,10 @@ void ActionManager::createCalendarAkonadi()
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     mCollectionSelectionModelStateSaver = new KViewStateMaintainer<Akonadi::ETMViewStateSaver>(config->group(QStringLiteral("GlobalCollectionSelection")));
     mCollectionSelectionModelStateSaver->setSelectionModel(calendar()->checkableProxyModel()->selectionModel());
+    connect(calendar()->checkableProxyModel()->selectionModel(),
+            &QItemSelectionModel::selectionChanged,
+            mCollectionSelectionModelStateSaver,
+            &KViewStateMaintainer<Akonadi::ETMViewStateSaver>::saveState);
 
     AkonadiCollectionViewFactory factory(mCalendarView);
     mCalendarView->addExtension(&factory);
